pub enum PersonalityError {
Io(Error),
Parse(Error),
Validation(Vec<String>),
}Expand description
Errors that can occur when loading or validating a personality TOML file.
Variants
Io(Error)
File could not be read.
Parse(Error)
TOML content could not be parsed into the expected schema.
Validation(Vec<String>)
Parsed successfully but field values are invalid.